#!/bin/bash

if [ -f /etc/os-release ]; then
    . /etc/os-release
fi

ID=$(echo "$ID" | sed -r 's/\"//g')
VER=$(echo "$VERSION_ID" | sed -r 's/\"//g')
VER_TEMP=$(echo "$VER" | sed -r 's/\..*//')

CURRENT_PATH=`pwd`

cd ../lib

ln -sf libusbast.so.0.0.3 ./libusbast.so.0
ln -sf libusbast.so.0.0.3 ./libusbast.so

ln -sf libstdc.so.6.0.31 ./libstdc++.so.6.0.31
ln -sf libstdc.so.6.0.31 ./libstdc++.so.6
ln -sf libstdc.so.6.0.31 ./libstdc++.so
	   
ln -sf libcurl.so.4.8.0 ./libcurl.so.4
ln -sf libcurl.so.4.8.0 ./libcurl.so
	   
ln -sf libcrypto.so.3 ./libcrypto.so
ln -sf libssl.so.3 ./libssl.so
	   
ln -sf libvpx.so.6.2.0 ./libvpx.so.6.2
ln -sf libvpx.so.6.2.0 ./libvpx.so.6
ln -sf libvpx.so.6.2.0 ./libvpx.so
	   
ln -sf libxkbcommon.so.0.0.0 ./libxkbcommon.so.0
ln -sf libxkbcommon.so.0.0.0 ./libxkbcommon.so

rm -f libast*.so.2*
rm -f libhatls.so.2*
rm -f libstdc++.so.6.0.23
rm -f libcurl.so.4.5.0
rm -f libcurl.so.4.7.0
rm -f libssl.so.1.1
rm -f libcrypto.so.1.1
rm -f libcrypto.so.1
rm -f libssl.so.1
rm -f libusbast.so.0.0.1


cd $CURRENT_PATH

TYPE='assistant'
[[ -d /usr/share/cassistantd ]] && TYPE='cassistant'

SHARE='/usr/share/'$TYPE'd'
SERV='/lib/systemd/system/'$TYPE'.service'


if [[ -f $SHARE/runasts.sh ]]; then

	cat > $SHARE/runasts.sh << EOF
#!/bin/bash

INST_DIR="/opt/assistant"
. \$INST_DIR/scripts/get_version_os.sh

if [[ \$ID != "centos" && \$VER_TEMP != "8" ]]
then
    export LD_LIBRARY_PATH=\$INST_DIR/lib
fi


echo | tee -a /opt/assistant/log/daemon.log
echo "\$(date) Starting Assistant..." | tee -a /opt/assistant/log/daemon.log
exec \$INST_DIR/bin/asts \$1 >> /opt/assistant/log/daemon.log

exit 0
EOF
fi 


[[ -f $SHARE/runasts.sh ]] && chmod +x $SHARE/runasts.sh

if [[ -f $SERV ]]; then 
	sed -i "s/\/cassistantd\/runasts.sh$/\/cassistantd\/runasts.sh --console/" $SERV
	sed -i "s/ExecStop=\/usr\/bin\/killall.*/ExecStop=\/usr\/bin\/killall asts astrct assistant master slave ffmpeg/" $SERV
	systemctl daemon-reload
	systemctl start $TYPE.service
fi

SUDO_FILE="/etc/sudoers.d/assistant"

echo "root ALL=(ALL) /opt/assistant/bin/" > $SUDO_FILE
echo "root ALL=(ALL) /opt/assistant/scripts/" >> $SUDO_FILE
echo "root ALL=(ALL) /sbin/setcap" >> $SUDO_FILE
echo "Defaults env_keep += \"DISPLAY XAUTHORITY\"" >> $SUDO_FILE

[[ -f $SUDO_FILE ]] && chmod 0400 $SUDO_FILE


. /opt/assistant/scripts/setup.sh

cert --install
trusted --install
set_shell_ini --install
add_libudev_links --install

exit 0